@@ -1,2 +1,4 @@
+#!/bin/sh
+set -ux
 find src examples -name '*.py' | xargs pylint
 find src examples -name '*.py' | xargs mypy
